﻿* Encoding: UTF-8.
/*************************SPSS syntax file to estimate standard two-level meta-analytic models****************************************

* Syntax accompanies Multivariate Behavioral Research article titled: 
* "On the multilevel nature of meta-analysis: A tutorial, comparison of software programs, and discussion of analytic choices"
* by Dena A. Pastor and Rory A. Lazowski.

* Please send any questions to Dena Pastor: pastorda@jmu.edu.


*    Data set in this example is from Raudenbush (1984) and is in tab-delimited data file named teacher_expectancy.txt
*    The id variable is "study", the effect size is "yi", the within-study variance is "vi", and the moderator used in the example is "weeks".

*Six models are fit to the data using: 
	Fixed Effects model, no moderators
                         --MeanES macro
                         --MetaReg macro
 	Fixed Effects model, with moderators
                         --MetaReg macro
	Random Effects model, no moderators, DL estimation
                         --MeanES macro
                         --MetaReg macro
	Random Effects model, no moderators, ML estimation
                         --MetaReg macro
	Random Effects model, with moderators, DL estimation
                         --MetaReg macro
	Random Effects model, with moderators, ML estimation
                         --MetaReg macro
******************************************************************************************************************************************************/

*If you haven't done so already, download the SPSS macros from the following website: http://mason.gmu.edu/~dwilsonb/ma.html

*Within the double quotes put the path where the macros are stored. 

define !macropath () "C:\Users\Desktop\SPSS macros\" !enddefine. 

/******************************************************************************************************************************************************/

*Data set in this example is from Raudenbush (1984) and is in tab-delimited data file named teacher_expectancy.txt
*The id variable is "study", the effect size is "yi", the within-study variance is "vi", and the moderator used in the example is "weeks".

*Data file.
data list list
/study yi vi weeks.
begin data.
1	0.03	0.0156	2
2	0.12	0.0216	21
3	-0.14	0.0279	19
4	1.18	0.1391	0
5	0.26	0.1362	0
6	-0.06	0.0106	3
7	-0.02	0.0106	17
8	-0.32	0.0484	24
9	0.27	0.0269	0
10	0.80	0.0630	1
11	0.54	0.0912	0
12	0.18	0.0497	0
13	-0.02	0.0835	1
14	0.23	0.0841	2
15	-0.18	0.0253	17
16	-0.06	0.0279	5
17	0.30	0.0193	1
18	0.07	0.0088	2
19	-0.07	0.0303	7
end data.
exe.

*The SPSS macros use weights (w), not the sampling variance (vi) as input, so create a variable representing w for each study.
compute w=1/vi.
exe.

/***************************************************Fixed Effects Model, No Moderators****************************************************/

*MeanES macro provides common effect size for FE model & overall weighted effect size for RE model using the 
DerSimonian and Laird’s (DL; 1986) estimator.
include !macropath+"MeanES.sps".
MEANES    ES = yi    /W = w. 
exe.

*We can also obtain the FE model results using MetaReg macro.
*Note: If you run the macro above, you might not get results when you try to then run macro below.
*See WARNING at bottom of spss_readme.txt that comes along with download of SPSS macros.
*You may need to close SPSS, open it again, reread in data set and compute w, then run the analysis below.
include !macropath+"MetaReg.sps".
METAREG    ES =  yi     /W = w     /IVS=     /MODEL = fe.

/***************************************************Fixed Effects Model, Moderators*******************************************************/

include !macropath+"MetaReg.sps".
METAREG    ES=yi    /W=w    /IVS = weeks      /MODEL= fe.

/**************************************************Random Effects Model, No Moderators*************************************************/

*MeanES macro provides common effect size for FE model & overall weighted effect size for RE model using the 
DerSimonian and Laird’s (DL; 1986) estimator.
include !macropath+"MeanES.sps".
MEANES    ES = yi    /W = w. 
exe.

*We can also obtain the RE model results using MetaReg macro.
*Note: If you run the macro above, you might not get results when try to then run macro below.
*See WARNING at bottom of spss_readme.txt that comes along with download of SPSS macros.
*You may need to close SPSS, open it again, reread in data set and compute w, then run the analysis below.

*When /MODEL=MM is specificed, a RE model with the DerSimonian and Laird’s estimator (DL) is used.
include !macropath+"MetaReg.sps".
METAREG    ES =  yi     /W = w     /IVS=     /MODEL = MM.

*When /MODEL=ML is specificed, a RE model with full maximum likeilhood (ML) is used.
include !macropath+"MetaReg.sps".
METAREG    ES =  yi     /W = w     /IVS=     /MODEL = ML.

********************************Random Effects Model, Moderators*******************************.
*When /MODEL=MM is specificed, a RE model with the DerSimonian and Laird’s estimator (DL) is used.
include !macropath+"MetaReg.sps".
METAREG    ES =  yi     /W = w     /IVS= weeks     /MODEL = MM.

*When /MODEL=ML is specificed, a RE model with full maximum likeilhood (ML) is used.
include !macropath+"MetaReg.sps".
METAREG    ES =  yi     /W = w     /IVS=  weeks    /MODEL = ML

**********************************************************************************************************************************.
